@@ -484,6 +484,7 @@ class RedisRoot:
                                 value = real_value
                             elif django_field_param_name == 'remote_field':
                                 redis_field_param_name = 'model'
+                                print(django_field, django_field.__class__.__name__, value)
                                 if value is not None:
                                     value = value.model
                                     value = get_or_create_redis_model_from_django_model(value, redis_root)
@@ -513,7 +514,7 @@ class RedisRoot:
                     django_models.ManyToManyField: RedisManyToMany
                 }
 
-                print(django_field, django_field.__class__.__name__, django_field.__class__.__name__.endswith('Rel'))
+
 
                 if django_field.__class__.__name__.endswith('Rel'):
                     redis_field = None
